/*
 * 文 件 名:  BaseConverter
 * 版    权:  浩鲸云计算科技股份有限公司
 * 描    述:  <描述>
 * 修 改 人:  learshaw
 * 修改时间:  2019/8/5
 * 跟踪单号:  <跟踪单号>
 * 修改单号:  <修改单号>
 * 修改内容:  <修改内容>
 */
package com.huashe.citybrain.commons.base.bean;

import org.apache.commons.collections4.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * 对象转换工具
 * <功能详细描述>
 *
 * @author learshaw
 * @version [版本号, 2019/8/5]
 * @see [相关类/方法]
 * @since [产品/模块版本]
 */
public class BaseConverter<P, V> {
    public static final Logger log = LoggerFactory.getLogger(BaseConverter.class);

    /**
     * 单个对象转换
     *
     * @param from  单个PO
     * @param clazz 目标对象Class
     * @return 目标对象VO
     */
    public V convert(P from, Class<V> clazz) {
        if (from == null) {
            return null;
        }

        V to = null;

        try {
            to = clazz.newInstance();
        }
        catch (Exception e) {
            log.error("初始化{}对象失败。", clazz, e);
        }

        convert(from, to);
        return to;
    }

    /**
     * 对象列表转换
     *
     * @param fromList 待转换PO列表
     * @param clazz    目标对象Class
     * @return 目标对象列表
     */
    public List<V> convert(List<P> fromList, Class<V> clazz) {
        if (CollectionUtils.isEmpty(fromList)) {
            return new ArrayList<>();
        }

        List<V> toList = new ArrayList<>();

        for (P from : fromList) {
            toList.add(convert(from, clazz));
        }

        return toList;
    }

    /**
     * 属性拷贝方法，有特殊需求时子类覆写此方法
     */
    protected void convert(P from, V to) {
        BeanUtils.copyProperties(from, to);
    }
}