/*
 * 文 件 名:  FileUtils
 * 版    权:  浩鲸云计算科技股份有限公司
 * 描    述:  <描述>
 * 修 改 人:  0027008907/lv.wenbin
 * 修改时间:  2020/10/20
 * 跟踪单号:  <跟踪单号>
 * 修改单号:  <修改单号>
 * 修改内容:  <修改内容>
 */
package com.huashe.citybrain.commons.base.utils;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.Resource;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URL;

/**
 * 文件工具
 * <功能详细描述>
 *
 * @author 0027008907/lv.wenbin
 * @version [版本号, 2020/10/20]
 * @see [相关类/方法]
 * @since [产品/模块版本]
 */
public abstract class FileUtils {
    private static final Log logger = LogFactory.getLog(FileUtils.class);

    /**
     * 从网络取图片
     * @param strUrl
     * @return
     */
    public static BufferedImage getImageFromNetByUrl(String strUrl) {
        HttpURLConnection conn = null;
        InputStream inStream = null;
        BufferedImage image = null;

        try {
            URL url = new URL(strUrl);
            conn = (HttpURLConnection) url.openConnection();
            conn.setRequestMethod("GET");
            conn.setConnectTimeout(15 * 1000);
            // 通过输入流获取图片数据
            inStream = conn.getInputStream();
            image = ImageIO.read(inStream);
        }
        catch (Exception e) {
            logger.error("获取过车图片出现异常", e);
        }
        finally {
            CloseUtils.close(inStream);

            if (null != conn) {
                conn.disconnect();
            }
        }

        return image;
    }

    /**
     * 从本地取图片
     * @param file
     * @return
     */
    public static BufferedImage getImageFromPath(String file) {
        BufferedImage image = null;

        try {
            Resource resource = new ClassPathResource(file);
            image = ImageIO.read(resource.getInputStream());
        }
        catch (Exception e) {
            logger.error("获取默认图片出现异常:", e);
        }
        finally {
            CloseUtils.close(image);
        }

        return image;
    }
}