package com.ruoyi.ems.service.impl;

import com.ruoyi.ems.domain.EmsDeviceComponent;
import com.ruoyi.ems.mapper.EmsDeviceComponentMapper;
import com.ruoyi.ems.service.IEmsDeviceComponentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 能源设备部件Service业务层处理
 *
 * @author ruoyi
 * @date 2024-09-23
 */
@Service
public class EmsDeviceComponentServiceImpl implements IEmsDeviceComponentService {
    @Autowired
    private EmsDeviceComponentMapper componentMapper;

    /**
     * 查询能源设备部件
     *
     * @param id 能源设备部件主键
     * @return 能源设备部件
     */
    @Override
    public EmsDeviceComponent selectById(Long id) {
        return componentMapper.selectById(id);
    }

    @Override
    public EmsDeviceComponent selectByCode(String componentCode) {
        return componentMapper.selectByCode(componentCode);
    }

    /**
     * 查询能源设备部件列表
     *
     * @param deviceComponent 能源设备部件
     * @return 能源设备部件
     */
    @Override
    public List<EmsDeviceComponent> selectList(EmsDeviceComponent deviceComponent) {
        return componentMapper.selectList(deviceComponent);
    }

    /**
     * 根据设备编号查询能源设备部件
     *
     * @param deviceCode 设备编号
     * @return 能源设备部件
     */
    @Override
    public List<EmsDeviceComponent> selectByDeviceCode(String deviceCode) {
        return componentMapper.selectByDeviceCode(deviceCode);
    }

    /**
     * 新增能源设备部件
     *
     * @param deviceComponent 能源设备部件
     * @return 结果
     */
    @Override
    public int insertComponent(EmsDeviceComponent deviceComponent) {
        return componentMapper.insertComponent(deviceComponent);
    }

    /**
     * 修改能源设备部件
     *
     * @param deviceComponent 能源设备部件
     * @return 结果
     */
    @Override
    public int updateComponent(EmsDeviceComponent deviceComponent) {
        return componentMapper.updateComponent(deviceComponent);
    }

    /**
     * 批量删除能源设备部件
     *
     * @param ids 需要删除的能源设备部件主键
     * @return 结果
     */
    @Override
    public int deleteComponentByIds(Long[] ids) {
        return componentMapper.deleteComponentByIds(ids);
    }

    /**
     * 删除能源设备部件信息
     *
     * @param id 能源设备部件主键
     * @return 结果
     */
    @Override
    public int deleteComponentById(Long id) {
        return componentMapper.deleteComponentById(id);
    }
}
